import type { Bundle } from './bundle.js';
import { FunctionConfig } from './config.js';
import { Declaration } from './declaration.js';
import { EdgeFunction } from './edge_function.js';
import { FeatureFlags } from './feature_flags.js';
import { Layer } from './layer.js';
interface Route {
    function: string;
    pattern: string;
    excluded_patterns: string[];
    path?: string;
    methods?: string[];
}
export interface EdgeFunctionConfig {
    excluded_patterns: string[];
    on_error?: string;
    generator?: string;
    name?: string;
}
interface Manifest {
    bundler_version: string;
    bundles: {
        asset: string;
        format: string;
    }[];
    import_map?: string;
    layers: {
        name: string;
        flag: string;
    }[];
    routes: Route[];
    post_cache_routes: Route[];
    function_config: Record<string, EdgeFunctionConfig>;
}
interface GenerateManifestOptions {
    bundles?: Bundle[];
    declarations?: Declaration[];
    featureFlags?: FeatureFlags;
    functions: EdgeFunction[];
    importMap?: string;
    internalFunctionConfig?: Record<string, FunctionConfig>;
    layers?: Layer[];
    userFunctionConfig?: Record<string, FunctionConfig>;
}
declare const generateManifest: ({ bundles, declarations, functions, userFunctionConfig, internalFunctionConfig, importMap, layers, }: GenerateManifestOptions) => {
    declarationsWithoutFunction: string[];
    manifest: Manifest;
    unroutedFunctions: string[];
};
interface WriteManifestOptions extends GenerateManifestOptions {
    distDirectory: string;
}
declare const writeManifest: ({ distDirectory, ...rest }: WriteManifestOptions) => Promise<Manifest>;
export { generateManifest, Manifest, Route, writeManifest };
